aboutsummaryrefslogtreecommitdiffstats
path: root/src/gallium/tests/unit/pipe_barrier_test.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/gallium/tests/unit/pipe_barrier_test.c')
-rw-r--r--src/gallium/tests/unit/pipe_barrier_test.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/gallium/tests/unit/pipe_barrier_test.c b/src/gallium/tests/unit/pipe_barrier_test.c
index 58ad7e29630..6bd46b8d964 100644
--- a/src/gallium/tests/unit/pipe_barrier_test.c
+++ b/src/gallium/tests/unit/pipe_barrier_test.c
@@ -27,7 +27,7 @@
/*
* Test case for pipe_barrier.
*
* The test succeeds if no thread exits before all the other threads reach
* the barrier.
@@ -37,9 +37,9 @@
#include <stdio.h>
#include <stdlib.h>
-#include "os/os_thread.h"
#include "os/os_time.h"
#include "util/u_atomic.h"
+#include "util/u_thread.h"
#define NUM_THREADS 10
@@ -47,7 +47,7 @@
static int verbosity = 0;
static thrd_t threads[NUM_THREADS];
-static pipe_barrier barrier;
+static util_barrier barrier;
static int thread_ids[NUM_THREADS];
static volatile int waiting = 0;
@@ -78,7 +78,7 @@ thread_function(void *thread_data)
CHECK(p_atomic_read(&proceeded) == 0);
p_atomic_inc(&waiting);
- pipe_barrier_wait(&barrier);
+ util_barrier_wait(&barrier);
CHECK(p_atomic_read(&waiting) == NUM_THREADS);
@@ -109,7 +109,7 @@ int main(int argc, char *argv[])
LOG("pipe_barrier_test starting\n");
- pipe_barrier_init(&barrier, NUM_THREADS);
+ util_barrier_init(&barrier, NUM_THREADS);
for (i = 0; i < NUM_THREADS; i++) {
thread_ids[i] = i;
@@ -122,7 +122,7 @@ int main(int argc, char *argv[])
CHECK(p_atomic_read(&proceeded) == NUM_THREADS);
- pipe_barrier_destroy(&barrier);
+ util_barrier_destroy(&barrier);
LOG("pipe_barrier_test exiting\n");
@@ -27,7 +27,7 @@
/*
- * Test case for pipe_barrier.
+ * Test case for util_barrier.
*
* The test succeeds if no thread exits before all the other threads reach